import React, { useState, useEffect } from 'react';
import { data } from './data';

const Cell = ({ label, value, backgroundColor, isHighlighted }) => {
    return (
        <div
            className={`item svelte-rx74pf ${isHighlighted ? 'highlighted' : ''}`}
            style={{ padding: '0px 10px', color: 'var(--selected)', backgroundColor }}>
            <div className="label svelte-rx74pf">{label}</div>
            <div>{value}</div>
        </div>
    );
};

const getRandomItem = (array) => {
    return array[Math.floor(Math.random() * array.length)];
};

const generateCells = (length) => {
    return Array.from({ length }, () => {
        const randomItem = getRandomItem(data);
        return {
            label: randomItem.label,
            value: randomItem.value,
            backgroundColor: randomItem['background-color'],
        };
    });
};

const getRandomColor = () => {
    const colors = [
        'red', 'orange', 'yellow', 'lime', 'cyan', 'blue', 'magenta', 'pink',
        'coral', 'gold', 'chartreuse', 'aqua', 'dodgerblue', 'violet', 'fuchsia', 'orangered'
    ];
    return colors[Math.floor(Math.random() * colors.length)];
};

function AllCells() {
    const [cells, setCells] = useState(generateCells(1000));
    const [highlightedCells, setHighlightedCells] = useState({});

    useEffect(() => {
        const updateInterval = setInterval(() => {
            const randomIndex = Math.floor(Math.random() * cells.length);
            const newRandomItem = getRandomItem(data);
            const randomColor = getRandomColor();

            setCells(prevCells => {
                const newCells = [...prevCells];
                newCells[randomIndex] = {
                    label: newRandomItem.label,
                    value: newRandomItem.value,
                    backgroundColor: newRandomItem['background-color'],
                };
                return newCells.sort((a, b) => parseFloat(b.value) - parseFloat(a.value));
            });

            setHighlightedCells(prev => {
                const newHighlightedCells = { ...prev, [randomIndex]: randomColor };
                setTimeout(() => {
                    setHighlightedCells(current => {
                        const { [randomIndex]: _, ...rest } = current;
                        return rest;
                    });
                }, 2000);
                return newHighlightedCells;
            });
        }, 0); // Setting to 0 for as fast as possible updates

        return () => clearInterval(updateInterval);
    }, [cells.length]);

    useEffect(() => {
        const resetInterval = setInterval(() => {
            setCells(prevCells => prevCells.map(cell => ({
                ...cell,
                backgroundColor: 'black'
            })));
        }, 5000);

        return () => clearInterval(resetInterval);
    }, []);

    return (
        <>
            <style>
                {`
                    .grid {
                        display: flex;
                        flex-direction: column;
                        flex-wrap: wrap;
                        height: 100vh;
                        width: 100%;
                    }

                    .item {
                        display: flex;
                        justify-content: space-between;
                        align-items: center;
                        line-height: 1;
                        box-sizing: border-box;
                        flex: 0 0 auto;
                    }

                    .item:hover, .highlighted {
                        box-shadow: inset 0 0 0 1px var(--selected);
                    }

                    .label {
                        font-weight: 700;
                        opacity: var(--opacity);
                    }
                `}
            </style>
            <div className="grid" style={{ width: '100%' }}>
                {cells.map((item, index) => (
                    <Cell
                        key={index}
                        label={item.label}
                        value={item.value}
                        backgroundColor={highlightedCells[index] ? highlightedCells[index] : item.backgroundColor}
                    />
                ))}
            </div>
        </>
    );
}

function App() {
    return (
        <div style={{ display: 'contents' }}>
            <div
                data-sveltekit-reload="false"
                style={{ display: 'contents' }}>
                <div
                    className="layout-container svelte-ksy7ew"
                    id="__SOLID">
                    <nav className="__CONTAIN_STRICT cyber-solid svelte-1p683dt">
                        <div className="left svelte-1p683dt"><a
                            className="svg-container svelte-1p683dt"
                            data-svelte-h="svelte-19sct7q"
                            href="/">
                            <svg
                                height="16"
                                version="1.1"
                                viewBox="0 0 16 16"
                                width="16"
                                xmlns="http://www.w3.org/2000/svg">
                                <path
                                    d="m0 0v16h16v-3h-13v-10h13v-3z"
                                    fill="var(--action)"></path>
                            </svg>
                        </a>
                            <div className="tabs scroll-bt solid-scroll svelte-1p683dt"><a
                                className="tab cyber-solid--hover svelte-1p683dt"
                                href="/helix">Helix</a><a
                                className="tab cyber-solid--hover svelte-1p683dt"
                                href="/table">Table</a><a
                                className="tab cyber-solid--hover svelte-1p683dt"
                                href="/cube">Cube</a><a
                                className="tab cyber-solid--active svelte-1p683dt tab--active"
                                href="/grid">Grid</a><a
                                className="tab cyber-solid--hover svelte-1p683dt"
                                href="/graph">Graph</a><a
                                className="tab cyber-solid--hover svelte-1p683dt"
                                href="/matrix">Matrix</a></div>
                        </div>
                        <div className="right svelte-1p683dt">
                            <button
                                className="btn-clean fullscreen svelte-1p683dt"
                                data-svelte-h="svelte-1e1wqbx">
                                <svg
                                    height="16"
                                    viewBox="0 0 16 16"
                                    width="16"
                                    xmlns="http://www.w3.org/2000/svg">
                                    <path
                                        d="M1.75 10a.75.75 0 0 1 .75.75v2.5c0 .138.112.25.25.25h2.5a.75.75 0 0 1 0 1.5h-2.5A1.75 1.75 0 0 1 1 13.25v-2.5a.75.75 0 0 1 .75-.75Zm12.5 0a.75.75 0 0 1 .75.75v2.5A1.75 1.75 0 0 1 13.25 15h-2.5a.75.75 0 0 1 0-1.5h2.5a.25.25 0 0 0 .25-.25v-2.5a.75.75 0 0 1 .75-.75ZM2.75 2.5a.25.25 0 0 0-.25.25v2.5a.75.75 0 0 1-1.5 0v-2.5C1 1.784 1.784 1 2.75 1h2.5a.75.75 0 0 1 0 1.5ZM10 1.75a.75.75 0 0 1 .75-.75h2.5c.966 0 1.75.784 1.75 1.75v2.5a.75.75 0 0 1-1.5 0v-2.5a.25.25 0 0 0-.25-.25h-2.5a.75.75 0 0 1-.75-.75Z"
                                        fill="var(--selected)"></path>
                                </svg>
                                <span className="hidden-svg-button-text">Fullscreen</span></button>
                            <button className="btn-clean svelte-1p683dt">
                                <svg
                                    aria-hidden="true"
                                    focusable="false"
                                    height="16"
                                    viewBox="0 0 16 16"
                                    width="16"
                                    xmlns="http://www.w3.org/2000/svg">
                                    <path
                                        d="M6.823 7.823a.25.25 0 0 1 0 .354l-2.396 2.396A.25.25 0 0 1 4 10.396V5.604a.25.25 0 0 1 .427-.177Z"
                                        fill="var(--selected)"></path>
                                    <path
                                        d="M1.75 0h12.5C15.216 0 16 .784 16 1.75v12.5A1.75 1.75 0 0 1 14.25 16H1.75A1.75 1.75 0 0 1 0 14.25V1.75C0 .784.784 0 1.75 0ZM1.5 1.75v12.5c0 .138.112.25.25.25H9.5v-13H1.75a.25.25 0 0 0-.25.25ZM11 14.5h3.25a.25.25 0 0 0 .25-.25V1.75a.25.25 0 0 0-.25-.25H11Z"
                                        fill="var(--selected)"></path>
                                </svg>
                                <span
                                    className="hidden-svg-button-text"
                                    data-svelte-h="svelte-1j53zlh">Panel</span></button>
                        </div>
                    </nav>
                    <div
                        className="svelte-ksy7ew"
                        id="interface">
                        <div
                            className="__CONTAIN_STRICT svelte-ksy7ew"
                            id="viz">
                            <div
                                className="svelte-1aooc2x"
                                id="container">
                                <canvas className="svelte-1hcflc8"></canvas>
                                <div className="container svelte-16fs0xe">
                                    <div style={{width: '0px'}}></div>
                                    <div
                                        className="grid svelte-16fs0xe"
                                        style={{fontSize: '14px', gridTemplateColumns: 'repeat(9, 1fr)'}}>
                                        <div>
                                            <AllCells />
                                        </div>
                                    </div>
                                </div>
                            </div>
                            <div
                                className="cyber-solid svelte-1aooc2x"
                                id="controls">
                                <div className="left svelte-1aooc2x">Font: <span className="color-selected">14</span>px</div>
                                <button
                                    className="btn-clean page-btn svelte-1aooc2x"
                                    disabled>&lt;
                                </button>
                                <div className="page svelte-1aooc2x"><span className="color-selected">1</span>/2</div>
                                <button className="btn-clean page-btn svelte-1aooc2x">&gt;</button>
                                <div className="right svelte-1aooc2x">Visible: <span className="color-selected">162</span>/270</div>
                            </div>
                        </div>
                        <div
                            className="__CONTAIN_STRICT svelte-ksy7ew"
                            id="panel">
                            <div
                                className="svelte-ksy7ew"
                                id="header"><h1 className="svelte-ksy7ew">Grid</h1>
                                <button
                                    className="btn-clean panel-close-btn svelte-ksy7ew"
                                    data-svelte-h="svelte-1lqqio7">x
                                </button>
                            </div>
                            <div className="header svelte-pvqyok">
                                <button className="btn-clean btn-primary svelte-pvqyok">
                                    <div className="left svelte-pvqyok">
                                        <div
                                            className="arrow svelte-pvqyok rotate"
                                            data-svelte-h="svelte-86tpz1">&gt;
                                        </div>
                                        <h2>Settings</h2></div>
                                </button>
                            </div>
                            <div className="content solid-scroll scroll-bl svelte-ksy7ew">
                                <div className="group svelte-1a0e7j7">Data</div>
                                <div className="control control-line svelte-1a0e7j7">
                                    <div className="label label-1-line svelte-1a0e7j7">Value</div>
                                    <div className="select svelte-11srbeb">
                                        <button className="selected svelte-11srbeb">Price USD
                                            <svg
                                                height="16"
                                                style={{width: '8px', height: '8px'}}
                                                viewBox="0 0 16 16"
                                                width="16"
                                                xmlns="http://www.w3.org/2000/svg">
                                                <path
                                                    d="M16 .082L7.938 16 0 0z"
                                                    fill="var(--action)"></path>
                                            </svg>
                                        </button>
                                    </div>
                                </div>
                                <div className="control control-line svelte-1a0e7j7">
                                    <div className="label label-1-line svelte-1a0e7j7">Show Quote</div>
                                    <label className="toggle svelte-uw4hcd"><input
                                        className="svelte-uw4hcd"
                                        type="checkbox"/> <span className="dot svelte-uw4hcd"></span></label></div>
                                <hr/>
                                <div className="group svelte-1a0e7j7">Sort</div>
                                <div className="control control-line svelte-1a0e7j7">
                                    <div className="label label-1-line svelte-1a0e7j7">Sort By</div>
                                    <div className="select svelte-11srbeb">
                                        <button className="selected svelte-11srbeb">24H Change %
                                            <svg
                                                height="16"
                                                style={{width: '8px', height: '8px'}}
                                                viewBox="0 0 16 16"
                                                width="16"
                                                xmlns="http://www.w3.org/2000/svg">
                                                <path
                                                    d="M16 .082L7.938 16 0 0z"
                                                    fill="var(--action)"></path>
                                            </svg>
                                        </button>
                                    </div>
                                </div>
                                <div className="control svelte-1a0e7j7">
                                    <div className="label label-2-line svelte-1a0e7j7">Sort Direction</div>
                                    <div className="options svelte-10covav">
                                        <button className="option svelte-10covav btn--selected">Desc</button>
                                        <button className="option svelte-10covav">Asc</button>
                                    </div>
                                </div>
                                <hr/>
                                <div className="group svelte-1a0e7j7">Number Format</div>
                                <div className="control control-line svelte-1a0e7j7">
                                    <div className="label label-1-line svelte-1a0e7j7">Decimals</div>
                                    <div className="buttons svelte-1lot7sm">
                                        <button className="svelte-1lot7sm">-</button>
                                        <input
                                            lang="en"
                                            max="9"
                                            min="1"
                                            required=""
                                            step="1"
                                            style={{width: '48px'}}
                                            type="number"/>
                                        <button className="svelte-1lot7sm">+</button>
                                    </div>
                                </div>
                                <div className="control svelte-1a0e7j7">
                                    <div className="container svelte-1simsee"><input
                                        className="slider svelte-1simsee"
                                        max="9"
                                        min="1"
                                        step="1"
                                        type="range"/></div>
                                </div>
                                <div className="control control-line svelte-1a0e7j7">
                                    <div className="label label-1-line svelte-1a0e7j7">Group Digits</div>
                                    <label className="toggle svelte-uw4hcd"><input
                                        className="svelte-uw4hcd"
                                        type="checkbox"/> <span className="dot svelte-uw4hcd"></span></label></div>
                                <hr/>
                                <div className="group svelte-1a0e7j7">Font Size</div>
                                <div className="control control-line svelte-1a0e7j7">
                                    <div className="label label-1-line svelte-1a0e7j7">Min Font Size</div>
                                    <div className="buttons svelte-1lot7sm">
                                        <button className="svelte-1lot7sm">-</button>
                                        <input
                                            lang="en"
                                            max="100"
                                            min="8"
                                            required=""
                                            step="1"
                                            style={{width: '48px'}}
                                            type="number"/>
                                        <button className="svelte-1lot7sm">+</button>
                                    </div>
                                </div>
                                <div className="control svelte-1a0e7j7">
                                    <div className="container svelte-1simsee"><input
                                        className="slider svelte-1simsee"
                                        max="100"
                                        min="8"
                                        step="1"
                                        type="range"/></div>
                                </div>
                                <hr/>
                                <div className="group svelte-1a0e7j7">Padding</div>
                                <div className="control control-line svelte-1a0e7j7">
                                    <div className="label label-1-line svelte-1a0e7j7">Min x-Padding</div>
                                    <div className="buttons svelte-1lot7sm">
                                        <button className="svelte-1lot7sm">-</button>
                                        <input
                                            lang="en"
                                            max="100"
                                            min="0"
                                            required=""
                                            step="1"
                                            style={{width: '48px'}}
                                            type="number"/>
                                        <button className="svelte-1lot7sm">+</button>
                                    </div>
                                </div>
                                <div className="control svelte-1a0e7j7">
                                    <div className="container svelte-1simsee"><input
                                        className="slider svelte-1simsee"
                                        max="100"
                                        min="0"
                                        step="1"
                                        type="range"/></div>
                                </div>
                                <div className="control control-line svelte-1a0e7j7">
                                    <div className="label label-1-line svelte-1a0e7j7">Min y-Padding</div>
                                    <div className="buttons svelte-1lot7sm">
                                        <button className="svelte-1lot7sm">-</button>
                                        <input
                                            lang="en"
                                            max="100"
                                            min="0"
                                            required=""
                                            step="1"
                                            style={{width: '48px'}}
                                            type="number"/>
                                        <button className="svelte-1lot7sm">+</button>
                                    </div>
                                </div>
                                <div className="control svelte-1a0e7j7">
                                    <div className="container svelte-1simsee"><input
                                        className="slider svelte-1simsee"
                                        max="100"
                                        min="0"
                                        step="1"
                                        type="range"/></div>
                                </div>
                                <hr/>
                                <div className="group svelte-1a0e7j7">Tween</div>
                                <div className="control control-line svelte-1a0e7j7">
                                    <div className="label label-1-line svelte-1a0e7j7">Tween Values</div>
                                    <label className="toggle svelte-uw4hcd"><input
                                        className="svelte-uw4hcd"
                                        type="checkbox"/> <span className="dot svelte-uw4hcd"></span></label></div>
                                <div className="control control-line svelte-1a0e7j7">
                                    <div className="label label-1-line svelte-1a0e7j7 label-indent">
                                        <div className="indent svelte-1a0e7j7"></div>
                                        Duration (s)
                                    </div>
                                    <div className="buttons svelte-1lot7sm">
                                        <button className="svelte-1lot7sm">-</button>
                                        <input
                                            lang="en"
                                            max="1"
                                            min="0.1"
                                            required=""
                                            step="0.1"
                                            style={{width: '48px'}}
                                            type="number"/>
                                        <button className="svelte-1lot7sm">+</button>
                                    </div>
                                </div>
                                <div className="control svelte-1a0e7j7">
                                    <div className="container svelte-1simsee"><input
                                        className="slider svelte-1simsee"
                                        max="1"
                                        min="0.1"
                                        step="0.1"
                                        type="range"/></div>
                                </div>
                            </div>
                            <div className="header svelte-pvqyok">
                                <button className="btn-clean btn-primary svelte-pvqyok">
                                    <div className="left svelte-pvqyok">
                                        <div
                                            className="arrow svelte-pvqyok rotate"
                                            data-svelte-h="svelte-86tpz1">&gt;
                                        </div>
                                        <h2>About</h2></div>
                                </button>
                            </div>
                            <main className="content solid-scroll scroll-bl select-text svelte-ksy7ew"><p>Fits as much data on a screen as possible, while allowing in-depth control of data density to
                                ensure
                                legibility. Pagination is used only when absolutely necessary.</p>
                                <p>Changing the density-relevant settings <code>Decimals</code>, <code>Group Digits</code>, <code>Min Font Size</code>, <code>Min x-Padding</code>, <code>Min
                                    y-Padding</code>
                                    does not always lead to a change in UI density, since it is determined by all parameters jointly or, as in the case of <code>Min Font Size</code>, <code>Min
                                        x-Padding</code>, <code>Min y-Padding</code>, is already realized since these are minimum values.</p></main>
                            <div
                                className="select-text svelte-ksy7ew"
                                id="contact">
                                <div
                                    className="select-text"
                                    data-svelte-h="svelte-18y5hgq">
                                    <span>hello</span><span className="inv svelte-17251gd">0</span><span>@</span><span className="inv svelte-17251gd">0</span><span>cybernetic</span><span className="inv svelte-17251gd">0</span><span>.</span><span>dev</span>
                                </div>
                            </div>
                        </div>
                    </div>
                    <div
                        className="__CONTAIN_STRICT solid-ws-bar cyber-solid svelte-1ha854r"
                        id="ws-status">
                        <div className="flex-gap svelte-1kiyls7">
                            <div className="align-center svelte-1kiyls7">
                                <div className="status-bullet svelte-1kiyls7"></div>
                                Connected<span
                                className="ws svelte-1kiyls7"
                                data-svelte-h="svelte-17k40cf"> to WebSocket API</span></div>
                            <div className="n svelte-1kiyls7">USD Markets: 270</div>
                            <div className="msgs svelte-1kiyls7">Received Messages: 906</div>
                        </div>
                        <div className="container svelte-1xaj2gx">Throttle <span
                            className="svelte-1xaj2gx"
                            data-svelte-h="svelte-h0puju"> Data </span> (s)
                            <button className="btn-clean btn-throttle-dec svelte-1xaj2gx">-</button>
                            <div className="value svelte-1xaj2gx">0.2</div>
                            <button className="btn-clean btn-throttle-inc svelte-1xaj2gx">+</button>
                        </div>
                    </div>
                </div>
            </div>
            <div
                aria-atomic="true"
                aria-live="assertive"
                id="svelte-announcer"
                style={{
                    position: 'absolute',
                    left: '0px',
                    top: '0px',
                    clip: 'rect(0px, 0px, 0px, 0px)',
                    clipPath: 'inset(50%)',
                    overflow: 'hidden',
                    whiteSpace: 'nowrap',
                    width: '1px',
                    height: '1px'
                }}></div>
        </div>
    );
}

export default App;
